# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .file import File
from .minithumbnail import Minithumbnail
from ..base_object import BaseObject


class ChatPhotoInfo(BaseObject):
    """
    Contains basic information about the photo of a chat
    
    Params:
        small (:class:`File`)
            A small (160x160) chat photo variant in JPEG format. The file can be downloaded only before the photo is changed
        
        big (:class:`File`)
            A big (640x640) chat photo variant in JPEG format. The file can be downloaded only before the photo is changed
        
        minithumbnail (:class:`Minithumbnail`)
            Chat photo minithumbnail; may be null
        
        has_animation (:class:`bool`)
            True, if the photo has animated variant
        
    """

    ID: str = Field("chatPhotoInfo", alias="@type")
    small: File
    big: File
    minithumbnail: typing.Optional[Minithumbnail] = None
    has_animation: bool

    @staticmethod
    def read(q: dict) -> ChatPhotoInfo:
        return ChatPhotoInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .minithumbnail import Minithumbnail
from .photo_size import PhotoSize
from ..base_object import BaseObject


class Photo(BaseObject):
    """
    Describes a photo
    
    Params:
        has_stickers (:class:`bool`)
            True, if stickers were added to the photo. The list of corresponding sticker sets can be received using getAttachedStickerSets
        
        minithumbnail (:class:`Minithumbnail`)
            Photo minithumbnail; may be null
        
        sizes (:obj:`list[PhotoSize]`)
            Available variants of the photo, in different sizes
        
    """

    ID: str = Field("photo", alias="@type")
    has_stickers: bool
    minithumbnail: typing.Optional[Minithumbnail] = None
    sizes: list[PhotoSize]

    @staticmethod
    def read(q: dict) -> Photo:
        return Photo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetMessageEmbeddingCode(BaseObject):
    """
    Returns an HTML code for embedding the message. Available only for messages in supergroups and channels with a username
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to which the message belongs
        
        message_id (:class:`int`)
            Identifier of the message
        
        for_album (:class:`bool`)
            Pass true to return an HTML code for embedding of the whole media album
        
    """

    ID: str = Field("getMessageEmbeddingCode", alias="@type")
    chat_id: int
    message_id: int
    for_album: bool

    @staticmethod
    def read(q: dict) -> GetMessageEmbeddingCode:
        return GetMessageEmbeddingCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DiscardCall(BaseObject):
    """
    Discards a call
    
    Params:
        call_id (:class:`int`)
            Call identifier
        
        is_disconnected (:class:`bool`)
            True, if the user was disconnected
        
        duration (:class:`int`)
            The call duration, in seconds
        
        is_video (:class:`bool`)
            True, if the call was a video call
        
        connection_id (:class:`int`)
            Identifier of the connection used during the call
        
    """

    ID: str = Field("discardCall", alias="@type")
    call_id: int
    is_disconnected: bool
    duration: int
    is_video: bool
    connection_id: int

    @staticmethod
    def read(q: dict) -> DiscardCall:
        return DiscardCall.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject


class SetBio(BaseObject):
    """
    Changes the bio of the current user
    
    Params:
        bio (:class:`str`)
            The new value of the user bio; 0-70 characters without line feeds
        
    """

    ID: str = Field("setBio", alias="@type")
    bio: typing.Optional[str] = Field(None, max_length=70)

    @staticmethod
    def read(q: dict) -> SetBio:
        return SetBio.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ToggleSupergroupSignMessages(BaseObject):
    """
    Toggles sender signatures messages sent in a channel; requires can_change_info administrator right
    
    Params:
        supergroup_id (:class:`int`)
            Identifier of the channel
        
        sign_messages (:class:`bool`)
            New value of sign_messages
        
    """

    ID: str = Field("toggleSupergroupSignMessages", alias="@type")
    supergroup_id: int
    sign_messages: bool

    @staticmethod
    def read(q: dict) -> ToggleSupergroupSignMessages:
        return ToggleSupergroupSignMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .statistical_graph import StatisticalGraph
from ..base_object import BaseObject


class MessageStatistics(BaseObject):
    """
    A detailed statistics about a message
    
    Params:
        message_interaction_graph (:class:`StatisticalGraph`)
            A graph containing number of message views and shares
        
    """

    ID: str = Field("messageStatistics", alias="@type")
    message_interaction_graph: StatisticalGraph

    @staticmethod
    def read(q: dict) -> MessageStatistics:
        return MessageStatistics.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ShippingOption


class AnswerShippingQuery(BaseObject):
    """
    Sets the result of a shipping query; for bots only
    
    Params:
        shipping_query_id (:class:`int`)
            Identifier of the shipping query
        
        shipping_options (:obj:`list[ShippingOption]`)
            Available shipping options
        
        error_message (:class:`str`)
            An error message, empty on success
        
    """

    ID: str = Field("answerShippingQuery", alias="@type")
    shipping_query_id: int
    shipping_options: list[ShippingOption]
    error_message: str

    @staticmethod
    def read(q: dict) -> AnswerShippingQuery:
        return AnswerShippingQuery.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .file import File
from .minithumbnail import Minithumbnail
from .thumbnail import Thumbnail
from ..base_object import BaseObject


class Animation(BaseObject):
    """
    Describes an animation file. The animation must be encoded in GIF or MPEG4 format
    
    Params:
        duration (:class:`int`)
            Duration of the animation, in seconds; as defined by the sender
        
        width (:class:`int`)
            Width of the animation
        
        height (:class:`int`)
            Height of the animation
        
        file_name (:class:`str`)
            Original name of the file; as defined by the sender
        
        mime_type (:class:`str`)
            MIME type of the file, usually "image/gif" or "video/mp4"
        
        has_stickers (:class:`bool`)
            True, if stickers were added to the animation. The list of corresponding sticker set can be received using getAttachedStickerSets
        
        minithumbnail (:class:`Minithumbnail`)
            Animation minithumbnail; may be null
        
        thumbnail (:class:`Thumbnail`)
            Animation thumbnail in JPEG or MPEG4 format; may be null
        
        animation (:class:`File`)
            File containing the animation
        
    """

    ID: str = Field("animation", alias="@type")
    duration: int
    width: int
    height: int
    file_name: str
    mime_type: str
    has_stickers: bool
    minithumbnail: typing.Optional[Minithumbnail] = None
    thumbnail: typing.Optional[Thumbnail] = None
    animation: File

    @staticmethod
    def read(q: dict) -> Animation:
        return Animation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .address import Address
from .identity_document import IdentityDocument
from .personal_details import PersonalDetails
from .personal_document import PersonalDocument
from ..base_object import BaseObject


class PassportElement(BaseObject):
    """
    Contains information about a Telegram Passport element
    
    """

    ID: str = Field("passportElement", alias="@type")


class PassportElementAddress(PassportElement):
    """
    A Telegram Passport element containing the user's address
    
    Params:
        address (:class:`Address`)
            Address
        
    """

    ID: str = Field("passportElementAddress", alias="@type")
    address: Address

    @staticmethod
    def read(q: dict) -> PassportElementAddress:
        return PassportElementAddress.construct(**q)


class PassportElementBankStatement(PassportElement):
    """
    A Telegram Passport element containing the user's bank statement
    
    Params:
        bank_statement (:class:`PersonalDocument`)
            Bank statement
        
    """

    ID: str = Field("passportElementBankStatement", alias="@type")
    bank_statement: PersonalDocument

    @staticmethod
    def read(q: dict) -> PassportElementBankStatement:
        return PassportElementBankStatement.construct(**q)


class PassportElementDriverLicense(PassportElement):
    """
    A Telegram Passport element containing the user's driver license
    
    Params:
        driver_license (:class:`IdentityDocument`)
            Driver license
        
    """

    ID: str = Field("passportElementDriverLicense", alias="@type")
    driver_license: IdentityDocument

    @staticmethod
    def read(q: dict) -> PassportElementDriverLicense:
        return PassportElementDriverLicense.construct(**q)


class PassportElementEmailAddress(PassportElement):
    """
    A Telegram Passport element containing the user's email address
    
    Params:
        email_address (:class:`str`)
            Email address
        
    """

    ID: str = Field("passportElementEmailAddress", alias="@type")
    email_address: str

    @staticmethod
    def read(q: dict) -> PassportElementEmailAddress:
        return PassportElementEmailAddress.construct(**q)


class PassportElementIdentityCard(PassportElement):
    """
    A Telegram Passport element containing the user's identity card
    
    Params:
        identity_card (:class:`IdentityDocument`)
            Identity card
        
    """

    ID: str = Field("passportElementIdentityCard", alias="@type")
    identity_card: IdentityDocument

    @staticmethod
    def read(q: dict) -> PassportElementIdentityCard:
        return PassportElementIdentityCard.construct(**q)


class PassportElementInternalPassport(PassportElement):
    """
    A Telegram Passport element containing the user's internal passport
    
    Params:
        internal_passport (:class:`IdentityDocument`)
            Internal passport
        
    """

    ID: str = Field("passportElementInternalPassport", alias="@type")
    internal_passport: IdentityDocument

    @staticmethod
    def read(q: dict) -> PassportElementInternalPassport:
        return PassportElementInternalPassport.construct(**q)


class PassportElementPassport(PassportElement):
    """
    A Telegram Passport element containing the user's passport
    
    Params:
        passport (:class:`IdentityDocument`)
            Passport
        
    """

    ID: str = Field("passportElementPassport", alias="@type")
    passport: IdentityDocument

    @staticmethod
    def read(q: dict) -> PassportElementPassport:
        return PassportElementPassport.construct(**q)


class PassportElementPassportRegistration(PassportElement):
    """
    A Telegram Passport element containing the user's passport registration pages
    
    Params:
        passport_registration (:class:`PersonalDocument`)
            Passport registration pages
        
    """

    ID: str = Field("passportElementPassportRegistration", alias="@type")
    passport_registration: PersonalDocument

    @staticmethod
    def read(q: dict) -> PassportElementPassportRegistration:
        return PassportElementPassportRegistration.construct(**q)


class PassportElementPersonalDetails(PassportElement):
    """
    A Telegram Passport element containing the user's personal details
    
    Params:
        personal_details (:class:`PersonalDetails`)
            Personal details of the user
        
    """

    ID: str = Field("passportElementPersonalDetails", alias="@type")
    personal_details: PersonalDetails

    @staticmethod
    def read(q: dict) -> PassportElementPersonalDetails:
        return PassportElementPersonalDetails.construct(**q)


class PassportElementPhoneNumber(PassportElement):
    """
    A Telegram Passport element containing the user's phone number
    
    Params:
        phone_number (:class:`str`)
            Phone number
        
    """

    ID: str = Field("passportElementPhoneNumber", alias="@type")
    phone_number: str

    @staticmethod
    def read(q: dict) -> PassportElementPhoneNumber:
        return PassportElementPhoneNumber.construct(**q)


class PassportElementRentalAgreement(PassportElement):
    """
    A Telegram Passport element containing the user's rental agreement
    
    Params:
        rental_agreement (:class:`PersonalDocument`)
            Rental agreement
        
    """

    ID: str = Field("passportElementRentalAgreement", alias="@type")
    rental_agreement: PersonalDocument

    @staticmethod
    def read(q: dict) -> PassportElementRentalAgreement:
        return PassportElementRentalAgreement.construct(**q)


class PassportElementTemporaryRegistration(PassportElement):
    """
    A Telegram Passport element containing the user's temporary registration
    
    Params:
        temporary_registration (:class:`PersonalDocument`)
            Temporary registration
        
    """

    ID: str = Field("passportElementTemporaryRegistration", alias="@type")
    temporary_registration: PersonalDocument

    @staticmethod
    def read(q: dict) -> PassportElementTemporaryRegistration:
        return PassportElementTemporaryRegistration.construct(**q)


class PassportElementUtilityBill(PassportElement):
    """
    A Telegram Passport element containing the user's utility bill
    
    Params:
        utility_bill (:class:`PersonalDocument`)
            Utility bill
        
    """

    ID: str = Field("passportElementUtilityBill", alias="@type")
    utility_bill: PersonalDocument

    @staticmethod
    def read(q: dict) -> PassportElementUtilityBill:
        return PassportElementUtilityBill.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PaymentResult(BaseObject):
    """
    Contains the result of a payment request
    
    Params:
        success (:class:`bool`)
            True, if the payment request was successful; otherwise the verification_url will be not empty
        
        verification_url (:class:`str`)
            URL for additional payment credentials verification
        
    """

    ID: str = Field("paymentResult", alias="@type")
    success: bool
    verification_url: str

    @staticmethod
    def read(q: dict) -> PaymentResult:
        return PaymentResult.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetUserProfilePhotos(BaseObject):
    """
    Returns the profile photos of a user. The result of this query may be outdated: some photos might have been deleted already
    
    Params:
        user_id (:class:`int`)
            User identifier
        
        offset (:class:`int`)
            The number of photos to skip; must be non-negative
        
        limit (:class:`int`)
            The maximum number of photos to be returned; up to 100
        
    """

    ID: str = Field("getUserProfilePhotos", alias="@type")
    user_id: int
    offset: int
    limit: int

    @staticmethod
    def read(q: dict) -> GetUserProfilePhotos:
        return GetUserProfilePhotos.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetChatInviteLinks(BaseObject):
    """
    Returns invite links for a chat created by specified administrator. Requires administrator privileges and can_invite_users right in the chat to get own links and owner privileges to get other links
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        creator_user_id (:class:`int`)
            User identifier of a chat administrator. Must be an identifier of the current user for non-owner
        
        is_revoked (:class:`bool`)
            Pass true if revoked links needs to be returned instead of active or expired
        
        offset_date (:class:`int`)
            Creation date of an invite link starting after which to return invite links; use 0 to get results from the beginning
        
        offset_invite_link (:class:`str`)
            Invite link starting after which to return invite links; use empty string to get results from the beginning
        
        limit (:class:`int`)
            The maximum number of invite links to return
        
    """

    ID: str = Field("getChatInviteLinks", alias="@type")
    chat_id: int
    creator_user_id: int
    is_revoked: bool
    offset_date: int
    offset_invite_link: str
    limit: int

    @staticmethod
    def read(q: dict) -> GetChatInviteLinks:
        return GetChatInviteLinks.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetRecentlyVisitedTMeUrls(BaseObject):
    """
    Returns t.me URLs recently visited by a newly registered user
    
    Params:
        referrer (:class:`str`)
            Google Play referrer to identify the user
        
    """

    ID: str = Field("getRecentlyVisitedTMeUrls", alias="@type")
    referrer: str

    @staticmethod
    def read(q: dict) -> GetRecentlyVisitedTMeUrls:
        return GetRecentlyVisitedTMeUrls.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .user_privacy_setting_rule import UserPrivacySettingRule
from ..base_object import BaseObject


class UserPrivacySettingRules(BaseObject):
    """
    A list of privacy rules. Rules are matched in the specified order. The first matched rule defines the privacy setting for a given user. If no rule matches, the action is not allowed
    
    Params:
        rules (:obj:`list[UserPrivacySettingRule]`)
            A list of rules
        
    """

    ID: str = Field("userPrivacySettingRules", alias="@type")
    rules: list[UserPrivacySettingRule]

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRules:
        return UserPrivacySettingRules.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class SetStickerSetThumbnail(BaseObject):
    """
    Sets a sticker set thumbnail; for bots only. Returns the sticker set
    
    Params:
        user_id (:class:`int`)
            Sticker set owner
        
        name (:class:`str`)
            Sticker set name
        
        thumbnail (:class:`InputFile`)
            Thumbnail to set in PNG or TGS format. Animated thumbnail must be set for animated sticker sets and only for them. Pass a zero InputFileId to delete the thumbnail
        
    """

    ID: str = Field("setStickerSetThumbnail", alias="@type")
    user_id: int
    name: str
    thumbnail: InputFile

    @staticmethod
    def read(q: dict) -> SetStickerSetThumbnail:
        return SetStickerSetThumbnail.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class NotificationSettingsScope(BaseObject):
    """
    Describes the types of chats to which notification settings are relevant
    
    """

    ID: str = Field("notificationSettingsScope", alias="@type")


class NotificationSettingsScopeChannelChats(NotificationSettingsScope):
    """
    Notification settings applied to all channels when the corresponding chat setting has a default value
    
    """

    ID: str = Field("notificationSettingsScopeChannelChats", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationSettingsScopeChannelChats:
        return NotificationSettingsScopeChannelChats.construct(**q)


class NotificationSettingsScopeGroupChats(NotificationSettingsScope):
    """
    Notification settings applied to all basic groups and supergroups when the corresponding chat setting has a default value
    
    """

    ID: str = Field("notificationSettingsScopeGroupChats", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationSettingsScopeGroupChats:
        return NotificationSettingsScopeGroupChats.construct(**q)


class NotificationSettingsScopePrivateChats(NotificationSettingsScope):
    """
    Notification settings applied to all private and secret chats when the corresponding chat setting has a default value
    
    """

    ID: str = Field("notificationSettingsScopePrivateChats", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationSettingsScopePrivateChats:
        return NotificationSettingsScopePrivateChats.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CallProblem(BaseObject):
    """
    Describes the exact type of a problem with a call
    
    """

    ID: str = Field("callProblem", alias="@type")


class CallProblemDistortedSpeech(CallProblem):
    """
    The speech was distorted
    
    """

    ID: str = Field("callProblemDistortedSpeech", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemDistortedSpeech:
        return CallProblemDistortedSpeech.construct(**q)


class CallProblemDistortedVideo(CallProblem):
    """
    The video was distorted
    
    """

    ID: str = Field("callProblemDistortedVideo", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemDistortedVideo:
        return CallProblemDistortedVideo.construct(**q)


class CallProblemDropped(CallProblem):
    """
    The call ended unexpectedly
    
    """

    ID: str = Field("callProblemDropped", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemDropped:
        return CallProblemDropped.construct(**q)


class CallProblemEcho(CallProblem):
    """
    The user heard their own voice
    
    """

    ID: str = Field("callProblemEcho", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemEcho:
        return CallProblemEcho.construct(**q)


class CallProblemInterruptions(CallProblem):
    """
    The other side kept disappearing
    
    """

    ID: str = Field("callProblemInterruptions", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemInterruptions:
        return CallProblemInterruptions.construct(**q)


class CallProblemNoise(CallProblem):
    """
    The user heard background noise
    
    """

    ID: str = Field("callProblemNoise", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemNoise:
        return CallProblemNoise.construct(**q)


class CallProblemPixelatedVideo(CallProblem):
    """
    The video was pixelated
    
    """

    ID: str = Field("callProblemPixelatedVideo", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemPixelatedVideo:
        return CallProblemPixelatedVideo.construct(**q)


class CallProblemSilentLocal(CallProblem):
    """
    The user couldn't hear the other side
    
    """

    ID: str = Field("callProblemSilentLocal", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemSilentLocal:
        return CallProblemSilentLocal.construct(**q)


class CallProblemSilentRemote(CallProblem):
    """
    The other side couldn't hear the user
    
    """

    ID: str = Field("callProblemSilentRemote", alias="@type")

    @staticmethod
    def read(q: dict) -> CallProblemSilentRemote:
        return CallProblemSilentRemote.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class RequestQrCodeAuthentication(BaseObject):
    """
    Requests QR code authentication by scanning a QR code on another logged in device. Works only when the current authorization state is authorizationStateWaitPhoneNumber, or if there is no pending authentication query and the current authorization state is authorizationStateWaitCode, authorizationStateWaitRegistration, or authorizationStateWaitPassword
    
    Params:
        other_user_ids (:obj:`list[int]`)
            List of user identifiers of other users currently using the application
        
    """

    ID: str = Field("requestQrCodeAuthentication", alias="@type")
    other_user_ids: list[int]

    @staticmethod
    def read(q: dict) -> RequestQrCodeAuthentication:
        return RequestQrCodeAuthentication.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckAuthenticationCode(BaseObject):
    """
    Checks the authentication code. Works only when the current authorization state is authorizationStateWaitCode
    
    Params:
        code (:class:`str`)
            The verification code received via SMS, Telegram message, phone call, or flash call
        
    """

    ID: str = Field("checkAuthenticationCode", alias="@type")
    code: str

    @staticmethod
    def read(q: dict) -> CheckAuthenticationCode:
        return CheckAuthenticationCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import LogStream


class SetLogStream(BaseObject):
    """
    Sets new log stream for internal logging of TDLib. Can be called synchronously
    
    Params:
        log_stream (:class:`LogStream`)
            New log stream
        
    """

    ID: str = Field("setLogStream", alias="@type")
    log_stream: LogStream

    @staticmethod
    def read(q: dict) -> SetLogStream:
        return SetLogStream.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .message import Message
from ..base_object import BaseObject


class FoundMessages(BaseObject):
    """
    Contains a list of messages found by a search
    
    Params:
        total_count (:class:`int`)
            Approximate total count of messages found; -1 if unknown
        
        messages (:obj:`list[Message]`)
            List of messages
        
        next_offset (:class:`str`)
            The offset for the next request. If empty, there are no more results
        
    """

    ID: str = Field("foundMessages", alias="@type")
    total_count: int
    messages: list[Message]
    next_offset: str

    @staticmethod
    def read(q: dict) -> FoundMessages:
        return FoundMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .chat_invite_link import ChatInviteLink
from .chat_location import ChatLocation
from .chat_member_status import ChatMemberStatus
from .chat_permissions import ChatPermissions
from .chat_photo import ChatPhoto
from .message import Message
from .message_sender import MessageSender
from ..base_object import BaseObject


class ChatEventAction(BaseObject):
    """
    Represents a chat event
    
    """

    ID: str = Field("chatEventAction", alias="@type")


class ChatEventDescriptionChanged(ChatEventAction):
    """
    The chat description was changed
    
    Params:
        old_description (:class:`str`)
            Previous chat description
        
        new_description (:class:`str`)
            New chat description
        
    """

    ID: str = Field("chatEventDescriptionChanged", alias="@type")
    old_description: str
    new_description: str

    @staticmethod
    def read(q: dict) -> ChatEventDescriptionChanged:
        return ChatEventDescriptionChanged.construct(**q)


class ChatEventInviteLinkDeleted(ChatEventAction):
    """
    A revoked chat invite link was deleted
    
    Params:
        invite_link (:class:`ChatInviteLink`)
            The invite link
        
    """

    ID: str = Field("chatEventInviteLinkDeleted", alias="@type")
    invite_link: ChatInviteLink

    @staticmethod
    def read(q: dict) -> ChatEventInviteLinkDeleted:
        return ChatEventInviteLinkDeleted.construct(**q)


class ChatEventInviteLinkEdited(ChatEventAction):
    """
    A chat invite link was edited
    
    Params:
        old_invite_link (:class:`ChatInviteLink`)
            Previous information about the invite link
        
        new_invite_link (:class:`ChatInviteLink`)
            New information about the invite link
        
    """

    ID: str = Field("chatEventInviteLinkEdited", alias="@type")
    old_invite_link: ChatInviteLink
    new_invite_link: ChatInviteLink

    @staticmethod
    def read(q: dict) -> ChatEventInviteLinkEdited:
        return ChatEventInviteLinkEdited.construct(**q)


class ChatEventInviteLinkRevoked(ChatEventAction):
    """
    A chat invite link was revoked
    
    Params:
        invite_link (:class:`ChatInviteLink`)
            The invite link
        
    """

    ID: str = Field("chatEventInviteLinkRevoked", alias="@type")
    invite_link: ChatInviteLink

    @staticmethod
    def read(q: dict) -> ChatEventInviteLinkRevoked:
        return ChatEventInviteLinkRevoked.construct(**q)


class ChatEventInvitesToggled(ChatEventAction):
    """
    The can_invite_users permission of a supergroup chat was toggled
    
    Params:
        can_invite_users (:class:`bool`)
            New value of can_invite_users permission
        
    """

    ID: str = Field("chatEventInvitesToggled", alias="@type")
    can_invite_users: bool

    @staticmethod
    def read(q: dict) -> ChatEventInvitesToggled:
        return ChatEventInvitesToggled.construct(**q)


class ChatEventIsAllHistoryAvailableToggled(ChatEventAction):
    """
    The is_all_history_available setting of a supergroup was toggled
    
    Params:
        is_all_history_available (:class:`bool`)
            New value of is_all_history_available
        
    """

    ID: str = Field("chatEventIsAllHistoryAvailableToggled", alias="@type")
    is_all_history_available: bool

    @staticmethod
    def read(q: dict) -> ChatEventIsAllHistoryAvailableToggled:
        return ChatEventIsAllHistoryAvailableToggled.construct(**q)


class ChatEventLinkedChatChanged(ChatEventAction):
    """
    The linked chat of a supergroup was changed
    
    Params:
        old_linked_chat_id (:class:`int`)
            Previous supergroup linked chat identifier
        
        new_linked_chat_id (:class:`int`)
            New supergroup linked chat identifier
        
    """

    ID: str = Field("chatEventLinkedChatChanged", alias="@type")
    old_linked_chat_id: int
    new_linked_chat_id: int

    @staticmethod
    def read(q: dict) -> ChatEventLinkedChatChanged:
        return ChatEventLinkedChatChanged.construct(**q)


class ChatEventLocationChanged(ChatEventAction):
    """
    The supergroup location was changed
    
    Params:
        old_location (:class:`ChatLocation`)
            Previous location; may be null
        
        new_location (:class:`ChatLocation`)
            New location; may be null
        
    """

    ID: str = Field("chatEventLocationChanged", alias="@type")
    old_location: typing.Optional[ChatLocation] = None
    new_location: typing.Optional[ChatLocation] = None

    @staticmethod
    def read(q: dict) -> ChatEventLocationChanged:
        return ChatEventLocationChanged.construct(**q)


class ChatEventMemberInvited(ChatEventAction):
    """
    A new chat member was invited
    
    Params:
        user_id (:class:`int`)
            New member user identifier
        
        status (:class:`ChatMemberStatus`)
            New member status
        
    """

    ID: str = Field("chatEventMemberInvited", alias="@type")
    user_id: int
    status: ChatMemberStatus

    @staticmethod
    def read(q: dict) -> ChatEventMemberInvited:
        return ChatEventMemberInvited.construct(**q)


class ChatEventMemberJoined(ChatEventAction):
    """
    A new member joined the chat
    
    """

    ID: str = Field("chatEventMemberJoined", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatEventMemberJoined:
        return ChatEventMemberJoined.construct(**q)


class ChatEventMemberJoinedByInviteLink(ChatEventAction):
    """
    A new member joined the chat by an invite link
    
    Params:
        invite_link (:class:`ChatInviteLink`)
            Invite link used to join the chat
        
    """

    ID: str = Field("chatEventMemberJoinedByInviteLink", alias="@type")
    invite_link: ChatInviteLink

    @staticmethod
    def read(q: dict) -> ChatEventMemberJoinedByInviteLink:
        return ChatEventMemberJoinedByInviteLink.construct(**q)


class ChatEventMemberLeft(ChatEventAction):
    """
    A member left the chat
    
    """

    ID: str = Field("chatEventMemberLeft", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatEventMemberLeft:
        return ChatEventMemberLeft.construct(**q)


class ChatEventMemberPromoted(ChatEventAction):
    """
    A chat member has gained/lost administrator status, or the list of their administrator privileges has changed
    
    Params:
        user_id (:class:`int`)
            Affected chat member user identifier
        
        old_status (:class:`ChatMemberStatus`)
            Previous status of the chat member
        
        new_status (:class:`ChatMemberStatus`)
            New status of the chat member
        
    """

    ID: str = Field("chatEventMemberPromoted", alias="@type")
    user_id: int
    old_status: ChatMemberStatus
    new_status: ChatMemberStatus

    @staticmethod
    def read(q: dict) -> ChatEventMemberPromoted:
        return ChatEventMemberPromoted.construct(**q)


class ChatEventMemberRestricted(ChatEventAction):
    """
    A chat member was restricted/unrestricted or banned/unbanned, or the list of their restrictions has changed
    
    Params:
        member_id (:class:`MessageSender`)
            Affected chat member identifier
        
        old_status (:class:`ChatMemberStatus`)
            Previous status of the chat member
        
        new_status (:class:`ChatMemberStatus`)
            New status of the chat member
        
    """

    ID: str = Field("chatEventMemberRestricted", alias="@type")
    member_id: MessageSender
    old_status: ChatMemberStatus
    new_status: ChatMemberStatus

    @staticmethod
    def read(q: dict) -> ChatEventMemberRestricted:
        return ChatEventMemberRestricted.construct(**q)


class ChatEventMessageDeleted(ChatEventAction):
    """
    A message was deleted
    
    Params:
        message (:class:`Message`)
            Deleted message
        
    """

    ID: str = Field("chatEventMessageDeleted", alias="@type")
    message: Message

    @staticmethod
    def read(q: dict) -> ChatEventMessageDeleted:
        return ChatEventMessageDeleted.construct(**q)


class ChatEventMessageEdited(ChatEventAction):
    """
    A message was edited
    
    Params:
        old_message (:class:`Message`)
            The original message before the edit
        
        new_message (:class:`Message`)
            The message after it was edited
        
    """

    ID: str = Field("chatEventMessageEdited", alias="@type")
    old_message: Message
    new_message: Message

    @staticmethod
    def read(q: dict) -> ChatEventMessageEdited:
        return ChatEventMessageEdited.construct(**q)


class ChatEventMessagePinned(ChatEventAction):
    """
    A message was pinned
    
    Params:
        message (:class:`Message`)
            Pinned message
        
    """

    ID: str = Field("chatEventMessagePinned", alias="@type")
    message: Message

    @staticmethod
    def read(q: dict) -> ChatEventMessagePinned:
        return ChatEventMessagePinned.construct(**q)


class ChatEventMessageTtlSettingChanged(ChatEventAction):
    """
    The message TTL setting was changed
    
    Params:
        old_message_ttl_setting (:class:`int`)
            Previous value of message_ttl_setting
        
        new_message_ttl_setting (:class:`int`)
            New value of message_ttl_setting
        
    """

    ID: str = Field("chatEventMessageTtlSettingChanged", alias="@type")
    old_message_ttl_setting: int
    new_message_ttl_setting: int

    @staticmethod
    def read(q: dict) -> ChatEventMessageTtlSettingChanged:
        return ChatEventMessageTtlSettingChanged.construct(**q)


class ChatEventMessageUnpinned(ChatEventAction):
    """
    A message was unpinned
    
    Params:
        message (:class:`Message`)
            Unpinned message
        
    """

    ID: str = Field("chatEventMessageUnpinned", alias="@type")
    message: Message

    @staticmethod
    def read(q: dict) -> ChatEventMessageUnpinned:
        return ChatEventMessageUnpinned.construct(**q)


class ChatEventPermissionsChanged(ChatEventAction):
    """
    The chat permissions was changed
    
    Params:
        old_permissions (:class:`ChatPermissions`)
            Previous chat permissions
        
        new_permissions (:class:`ChatPermissions`)
            New chat permissions
        
    """

    ID: str = Field("chatEventPermissionsChanged", alias="@type")
    old_permissions: ChatPermissions
    new_permissions: ChatPermissions

    @staticmethod
    def read(q: dict) -> ChatEventPermissionsChanged:
        return ChatEventPermissionsChanged.construct(**q)


class ChatEventPhotoChanged(ChatEventAction):
    """
    The chat photo was changed
    
    Params:
        old_photo (:class:`ChatPhoto`)
            Previous chat photo value; may be null
        
        new_photo (:class:`ChatPhoto`)
            New chat photo value; may be null
        
    """

    ID: str = Field("chatEventPhotoChanged", alias="@type")
    old_photo: typing.Optional[ChatPhoto] = None
    new_photo: typing.Optional[ChatPhoto] = None

    @staticmethod
    def read(q: dict) -> ChatEventPhotoChanged:
        return ChatEventPhotoChanged.construct(**q)


class ChatEventPollStopped(ChatEventAction):
    """
    A poll in a message was stopped
    
    Params:
        message (:class:`Message`)
            The message with the poll
        
    """

    ID: str = Field("chatEventPollStopped", alias="@type")
    message: Message

    @staticmethod
    def read(q: dict) -> ChatEventPollStopped:
        return ChatEventPollStopped.construct(**q)


class ChatEventSignMessagesToggled(ChatEventAction):
    """
    The sign_messages setting of a channel was toggled
    
    Params:
        sign_messages (:class:`bool`)
            New value of sign_messages
        
    """

    ID: str = Field("chatEventSignMessagesToggled", alias="@type")
    sign_messages: bool

    @staticmethod
    def read(q: dict) -> ChatEventSignMessagesToggled:
        return ChatEventSignMessagesToggled.construct(**q)


class ChatEventSlowModeDelayChanged(ChatEventAction):
    """
    The slow_mode_delay setting of a supergroup was changed
    
    Params:
        old_slow_mode_delay (:class:`int`)
            Previous value of slow_mode_delay
        
        new_slow_mode_delay (:class:`int`)
            New value of slow_mode_delay
        
    """

    ID: str = Field("chatEventSlowModeDelayChanged", alias="@type")
    old_slow_mode_delay: int
    new_slow_mode_delay: int

    @staticmethod
    def read(q: dict) -> ChatEventSlowModeDelayChanged:
        return ChatEventSlowModeDelayChanged.construct(**q)


class ChatEventStickerSetChanged(ChatEventAction):
    """
    The supergroup sticker set was changed
    
    Params:
        old_sticker_set_id (:class:`int`)
            Previous identifier of the chat sticker set; 0 if none
        
        new_sticker_set_id (:class:`int`)
            New identifier of the chat sticker set; 0 if none
        
    """

    ID: str = Field("chatEventStickerSetChanged", alias="@type")
    old_sticker_set_id: int
    new_sticker_set_id: int

    @staticmethod
    def read(q: dict) -> ChatEventStickerSetChanged:
        return ChatEventStickerSetChanged.construct(**q)


class ChatEventTitleChanged(ChatEventAction):
    """
    The chat title was changed
    
    Params:
        old_title (:class:`str`)
            Previous chat title
        
        new_title (:class:`str`)
            New chat title
        
    """

    ID: str = Field("chatEventTitleChanged", alias="@type")
    old_title: str
    new_title: str

    @staticmethod
    def read(q: dict) -> ChatEventTitleChanged:
        return ChatEventTitleChanged.construct(**q)


class ChatEventUsernameChanged(ChatEventAction):
    """
    The chat username was changed
    
    Params:
        old_username (:class:`str`)
            Previous chat username
        
        new_username (:class:`str`)
            New chat username
        
    """

    ID: str = Field("chatEventUsernameChanged", alias="@type")
    old_username: str
    new_username: str

    @staticmethod
    def read(q: dict) -> ChatEventUsernameChanged:
        return ChatEventUsernameChanged.construct(**q)


class ChatEventVoiceChatCreated(ChatEventAction):
    """
    A voice chat was created
    
    Params:
        group_call_id (:class:`int`)
            Identifier of the voice chat. The voice chat can be received through the method getGroupCall
        
    """

    ID: str = Field("chatEventVoiceChatCreated", alias="@type")
    group_call_id: int

    @staticmethod
    def read(q: dict) -> ChatEventVoiceChatCreated:
        return ChatEventVoiceChatCreated.construct(**q)


class ChatEventVoiceChatDiscarded(ChatEventAction):
    """
    A voice chat was discarded
    
    Params:
        group_call_id (:class:`int`)
            Identifier of the voice chat. The voice chat can be received through the method getGroupCall
        
    """

    ID: str = Field("chatEventVoiceChatDiscarded", alias="@type")
    group_call_id: int

    @staticmethod
    def read(q: dict) -> ChatEventVoiceChatDiscarded:
        return ChatEventVoiceChatDiscarded.construct(**q)


class ChatEventVoiceChatMuteNewParticipantsToggled(ChatEventAction):
    """
    The mute_new_participants setting of a voice chat was toggled
    
    Params:
        mute_new_participants (:class:`bool`)
            New value of the mute_new_participants setting
        
    """

    ID: str = Field("chatEventVoiceChatMuteNewParticipantsToggled", alias="@type")
    mute_new_participants: bool

    @staticmethod
    def read(q: dict) -> ChatEventVoiceChatMuteNewParticipantsToggled:
        return ChatEventVoiceChatMuteNewParticipantsToggled.construct(**q)


class ChatEventVoiceChatParticipantIsMutedToggled(ChatEventAction):
    """
    A voice chat participant was muted or unmuted
    
    Params:
        participant_id (:class:`MessageSender`)
            Identifier of the affected group call participant
        
        is_muted (:class:`bool`)
            New value of is_muted
        
    """

    ID: str = Field("chatEventVoiceChatParticipantIsMutedToggled", alias="@type")
    participant_id: MessageSender
    is_muted: bool

    @staticmethod
    def read(q: dict) -> ChatEventVoiceChatParticipantIsMutedToggled:
        return ChatEventVoiceChatParticipantIsMutedToggled.construct(**q)


class ChatEventVoiceChatParticipantVolumeLevelChanged(ChatEventAction):
    """
    A voice chat participant volume level was changed
    
    Params:
        participant_id (:class:`MessageSender`)
            Identifier of the affected group call participant
        
        volume_level (:class:`int`)
            New value of volume_level; 1-20000 in hundreds of percents
        
    """

    ID: str = Field("chatEventVoiceChatParticipantVolumeLevelChanged", alias="@type")
    participant_id: MessageSender
    volume_level: int

    @staticmethod
    def read(q: dict) -> ChatEventVoiceChatParticipantVolumeLevelChanged:
        return ChatEventVoiceChatParticipantVolumeLevelChanged.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetLogTagVerbosityLevel(BaseObject):
    """
    Sets the verbosity level for a specified TDLib internal log tag. Can be called synchronously
    
    Params:
        tag (:class:`str`)
            Logging tag to change verbosity level
        
        new_verbosity_level (:class:`int`)
            New verbosity level; 1-1024
        
    """

    ID: str = Field("setLogTagVerbosityLevel", alias="@type")
    tag: str
    new_verbosity_level: int

    @staticmethod
    def read(q: dict) -> SetLogTagVerbosityLevel:
        return SetLogTagVerbosityLevel.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class BackgroundFill(BaseObject):
    """
    Describes a fill of a background
    
    """

    ID: str = Field("backgroundFill", alias="@type")


class BackgroundFillFreeformGradient(BackgroundFill):
    """
    Describes a freeform gradient fill of a background
    
    Params:
        colors (:obj:`list[int]`)
            A list of 3 or 4 colors of the freeform gradients in the RGB24 format
        
    """

    ID: str = Field("backgroundFillFreeformGradient", alias="@type")
    colors: list[int]

    @staticmethod
    def read(q: dict) -> BackgroundFillFreeformGradient:
        return BackgroundFillFreeformGradient.construct(**q)


class BackgroundFillGradient(BackgroundFill):
    """
    Describes a gradient fill of a background
    
    Params:
        top_color (:class:`int`)
            A top color of the background in the RGB24 format
        
        bottom_color (:class:`int`)
            A bottom color of the background in the RGB24 format
        
        rotation_angle (:class:`int`)
            Clockwise rotation angle of the gradient, in degrees; 0-359. Should be always divisible by 45
        
    """

    ID: str = Field("backgroundFillGradient", alias="@type")
    top_color: int
    bottom_color: int
    rotation_angle: int

    @staticmethod
    def read(q: dict) -> BackgroundFillGradient:
        return BackgroundFillGradient.construct(**q)


class BackgroundFillSolid(BackgroundFill):
    """
    Describes a solid fill of a background
    
    Params:
        color (:class:`int`)
            A color of the background in the RGB24 format
        
    """

    ID: str = Field("backgroundFillSolid", alias="@type")
    color: int

    @staticmethod
    def read(q: dict) -> BackgroundFillSolid:
        return BackgroundFillSolid.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .formatted_text import FormattedText
from .proxy_type import ProxyType
from ..base_object import BaseObject


class InternalLinkType(BaseObject):
    """
    Describes an internal https://t.me or tg: link, which must be processed by the app in a special way
    
    """

    ID: str = Field("internalLinkType", alias="@type")


class InternalLinkTypeActiveSessions(InternalLinkType):
    """
    The link is a link to the active sessions section of the app. Use getActiveSessions to handle the link
    
    """

    ID: str = Field("internalLinkTypeActiveSessions", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeActiveSessions:
        return InternalLinkTypeActiveSessions.construct(**q)


class InternalLinkTypeAuthenticationCode(InternalLinkType):
    """
    The link contains an authentication code. Call checkAuthenticationCode with the code if the current authorization state is authorizationStateWaitCode
    
    Params:
        code (:class:`str`)
            The authentication code
        
    """

    ID: str = Field("internalLinkTypeAuthenticationCode", alias="@type")
    code: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeAuthenticationCode:
        return InternalLinkTypeAuthenticationCode.construct(**q)


class InternalLinkTypeBackground(InternalLinkType):
    """
    The link is a link to a background. Call searchBackground with the given background name to process the link
    
    Params:
        background_name (:class:`str`)
            Name of the background
        
    """

    ID: str = Field("internalLinkTypeBackground", alias="@type")
    background_name: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeBackground:
        return InternalLinkTypeBackground.construct(**q)


class InternalLinkTypeBotStart(InternalLinkType):
    """
    The link is a link to a chat with a Telegram bot. Call searchPublicChat with the given bot username, check that the user is a bot, show START button in the chat with the bot, and then call sendBotStartMessage with the given start parameter after the button is pressed
    
    Params:
        bot_username (:class:`str`)
            Username of the bot
        
        start_parameter (:class:`str`)
            The parameter to be passed to sendBotStartMessage
        
    """

    ID: str = Field("internalLinkTypeBotStart", alias="@type")
    bot_username: str
    start_parameter: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeBotStart:
        return InternalLinkTypeBotStart.construct(**q)


class InternalLinkTypeBotStartInGroup(InternalLinkType):
    """
    The link is a link to a Telegram bot, which is supposed to be added to a group chat. Call searchPublicChat with the given bot username, check that the user is a bot and can be added to groups, ask the current user to select a group to add the bot to, and then call sendBotStartMessage with the given start parameter and the chosen group chat. Bots can be added to a public group only by administrators of the group
    
    Params:
        bot_username (:class:`str`)
            Username of the bot
        
        start_parameter (:class:`str`)
            The parameter to be passed to sendBotStartMessage
        
    """

    ID: str = Field("internalLinkTypeBotStartInGroup", alias="@type")
    bot_username: str
    start_parameter: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeBotStartInGroup:
        return InternalLinkTypeBotStartInGroup.construct(**q)


class InternalLinkTypeChangePhoneNumber(InternalLinkType):
    """
    The link is a link to the change phone number section of the app
    
    """

    ID: str = Field("internalLinkTypeChangePhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeChangePhoneNumber:
        return InternalLinkTypeChangePhoneNumber.construct(**q)


class InternalLinkTypeChatInvite(InternalLinkType):
    """
    The link is a chat invite link. Call checkChatInviteLink to process the link
    
    """

    ID: str = Field("internalLinkTypeChatInvite", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeChatInvite:
        return InternalLinkTypeChatInvite.construct(**q)


class InternalLinkTypeFilterSettings(InternalLinkType):
    """
    The link is a link to the filter settings section of the app
    
    """

    ID: str = Field("internalLinkTypeFilterSettings", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeFilterSettings:
        return InternalLinkTypeFilterSettings.construct(**q)


class InternalLinkTypeGame(InternalLinkType):
    """
    The link is a link to a game. Call searchPublicChat with the given bot username, check that the user is a bot, ask the current user to select a group to send the game, and then call sendMessage with inputMessageGame
    
    Params:
        bot_username (:class:`str`)
            Username of the bot that owns the game
        
        game_short_name (:class:`str`)
            Short name of the game
        
    """

    ID: str = Field("internalLinkTypeGame", alias="@type")
    bot_username: str
    game_short_name: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeGame:
        return InternalLinkTypeGame.construct(**q)


class InternalLinkTypeLanguagePack(InternalLinkType):
    """
    The link is a link to a language pack. Call getLanguagePackInfo with the given language pack identifier to process the link
    
    Params:
        language_pack_id (:class:`str`)
            Language pack identifier
        
    """

    ID: str = Field("internalLinkTypeLanguagePack", alias="@type")
    language_pack_id: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeLanguagePack:
        return InternalLinkTypeLanguagePack.construct(**q)


class InternalLinkTypeMessage(InternalLinkType):
    """
    The link is a link to a Telegram message. Call getMessageLinkInfo to process the link
    
    """

    ID: str = Field("internalLinkTypeMessage", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeMessage:
        return InternalLinkTypeMessage.construct(**q)


class InternalLinkTypeMessageDraft(InternalLinkType):
    """
    The link contains a message draft text. A share screen needs to be shown to the user, then the chosen chat should be open and the text should be added to the input field
    
    Params:
        text (:class:`FormattedText`)
            Message draft text
        
        contains_link (:class:`bool`)
            True, if the first line of the text contains a link. If true, the input field needs to be focused and the text after the link should be selected
        
    """

    ID: str = Field("internalLinkTypeMessageDraft", alias="@type")
    text: FormattedText
    contains_link: bool

    @staticmethod
    def read(q: dict) -> InternalLinkTypeMessageDraft:
        return InternalLinkTypeMessageDraft.construct(**q)


class InternalLinkTypePassportDataRequest(InternalLinkType):
    """
    The link contains a request of Telegram passport data. Call getPassportAuthorizationForm to process the link if the link was received outside of the app, otherwise ignore it
    
    Params:
        bot_user_id (:class:`int`)
            User identifier of the service's bot
        
        scope (:class:`str`)
            Telegram Passport element types requested by the service
        
        public_key (:class:`str`)
            Service's public key
        
        nonce (:class:`str`)
            Unique request identifier provided by the service
        
        callback_url (:class:`str`)
            An HTTP URL to open once the request is finished or canceled with the parameter tg_passport=success or tg_passport=cancel respectively. If empty, then the link tgbot{bot_user_id}://passport/success or tgbot{bot_user_id}://passport/cancel needs to be opened instead
        
    """

    ID: str = Field("internalLinkTypePassportDataRequest", alias="@type")
    bot_user_id: int
    scope: str
    public_key: str
    nonce: str
    callback_url: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypePassportDataRequest:
        return InternalLinkTypePassportDataRequest.construct(**q)


class InternalLinkTypePhoneNumberConfirmation(InternalLinkType):
    """
    The link can be used to confirm ownership of a phone number to prevent account deletion. Call sendPhoneNumberConfirmationCode with the given hash and phone number to process the link
    
    Params:
        hash_ (:class:`str`)
            Hash value from the link
        
        phone_number (:class:`str`)
            Phone number value from the link
        
    """

    ID: str = Field("internalLinkTypePhoneNumberConfirmation", alias="@type")
    hash_: str = Field(..., alias='hash')
    phone_number: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypePhoneNumberConfirmation:
        return InternalLinkTypePhoneNumberConfirmation.construct(**q)


class InternalLinkTypeProxy(InternalLinkType):
    """
    The link is a link to a proxy. Call addProxy to process the link and add the proxy
    
    Params:
        server (:class:`str`)
            Proxy server IP address
        
        port (:class:`int`)
            Proxy server port
        
        type_ (:class:`ProxyType`)
            Type of the proxy
        
    """

    ID: str = Field("internalLinkTypeProxy", alias="@type")
    server: str
    port: int
    type_: ProxyType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> InternalLinkTypeProxy:
        return InternalLinkTypeProxy.construct(**q)


class InternalLinkTypePublicChat(InternalLinkType):
    """
    The link is a link to a chat by its username. Call searchPublicChat with the given chat username to process the link
    
    Params:
        chat_username (:class:`str`)
            Username of the chat
        
    """

    ID: str = Field("internalLinkTypePublicChat", alias="@type")
    chat_username: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypePublicChat:
        return InternalLinkTypePublicChat.construct(**q)


class InternalLinkTypeQrCodeAuthentication(InternalLinkType):
    """
    The link can be used to login the current user on another device, but it must be scanned from QR-code using in-app camera. An alert similar to "This code can be used to allow someone to log in to your Telegram account. To confirm Telegram login, please go to Settings > Devices > Scan QR and scan the code" needs to be shown
    
    """

    ID: str = Field("internalLinkTypeQrCodeAuthentication", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeQrCodeAuthentication:
        return InternalLinkTypeQrCodeAuthentication.construct(**q)


class InternalLinkTypeSettings(InternalLinkType):
    """
    The link is a link to app settings
    
    """

    ID: str = Field("internalLinkTypeSettings", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeSettings:
        return InternalLinkTypeSettings.construct(**q)


class InternalLinkTypeStickerSet(InternalLinkType):
    """
    The link is a link to a sticker set. Call searchStickerSet with the given sticker set name to process the link and show the sticker set
    
    Params:
        sticker_set_name (:class:`str`)
            Name of the sticker set
        
    """

    ID: str = Field("internalLinkTypeStickerSet", alias="@type")
    sticker_set_name: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeStickerSet:
        return InternalLinkTypeStickerSet.construct(**q)


class InternalLinkTypeTheme(InternalLinkType):
    """
    The link is a link to a theme. TDLib has no theme support yet
    
    Params:
        theme_name (:class:`str`)
            Name of the theme
        
    """

    ID: str = Field("internalLinkTypeTheme", alias="@type")
    theme_name: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeTheme:
        return InternalLinkTypeTheme.construct(**q)


class InternalLinkTypeThemeSettings(InternalLinkType):
    """
    The link is a link to the theme settings section of the app
    
    """

    ID: str = Field("internalLinkTypeThemeSettings", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeThemeSettings:
        return InternalLinkTypeThemeSettings.construct(**q)


class InternalLinkTypeUnknownDeepLink(InternalLinkType):
    """
    The link is an unknown tg: link. Call getDeepLinkInfo to process the link
    
    """

    ID: str = Field("internalLinkTypeUnknownDeepLink", alias="@type")

    @staticmethod
    def read(q: dict) -> InternalLinkTypeUnknownDeepLink:
        return InternalLinkTypeUnknownDeepLink.construct(**q)


class InternalLinkTypeVoiceChat(InternalLinkType):
    """
    The link is a link to a voice chat. Call searchPublicChat with the given chat username, and then joinGoupCall with the given invite hash to process the link
    
    Params:
        chat_username (:class:`str`)
            Username of the chat with the voice chat
        
        invite_hash (:class:`str`)
            If non-empty, invite hash to be used to join the voice chat without being muted by administrators
        
    """

    ID: str = Field("internalLinkTypeVoiceChat", alias="@type")
    chat_username: str
    invite_hash: str

    @staticmethod
    def read(q: dict) -> InternalLinkTypeVoiceChat:
        return InternalLinkTypeVoiceChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import PhoneNumberAuthenticationSettings


class SetAuthenticationPhoneNumber(BaseObject):
    """
    Sets the phone number of the user and sends an authentication code to the user. Works only when the current authorization state is authorizationStateWaitPhoneNumber, or if there is no pending authentication query and the current authorization state is authorizationStateWaitCode, authorizationStateWaitRegistration, or authorizationStateWaitPassword
    
    Params:
        phone_number (:class:`str`)
            The phone number of the user, in international format
        
        settings (:class:`PhoneNumberAuthenticationSettings`)
            Settings for the authentication of the user's phone number
        
    """

    ID: str = Field("setAuthenticationPhoneNumber", alias="@type")
    phone_number: str
    settings: PhoneNumberAuthenticationSettings

    @staticmethod
    def read(q: dict) -> SetAuthenticationPhoneNumber:
        return SetAuthenticationPhoneNumber.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .authentication_code_type import AuthenticationCodeType
from ..base_object import BaseObject


class AuthenticationCodeInfo(BaseObject):
    """
    Information about the authentication code that was sent
    
    Params:
        phone_number (:class:`str`)
            A phone number that is being authenticated
        
        type_ (:class:`AuthenticationCodeType`)
            Describes the way the code was sent to the user
        
        next_type (:class:`AuthenticationCodeType`)
            Describes the way the next code will be sent to the user; may be null
        
        timeout (:class:`int`)
            Timeout before the code can be re-sent, in seconds
        
    """

    ID: str = Field("authenticationCodeInfo", alias="@type")
    phone_number: str
    type_: AuthenticationCodeType = Field(..., alias='type')
    next_type: typing.Optional[AuthenticationCodeType] = None
    timeout: int

    @staticmethod
    def read(q: dict) -> AuthenticationCodeInfo:
        return AuthenticationCodeInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckChatUsername(BaseObject):
    """
    Checks whether a username can be set for a chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier; should be identifier of a supergroup chat, or a channel chat, or a private chat with self, or zero if the chat is being created
        
        username (:class:`str`)
            Username to be checked
        
    """

    ID: str = Field("checkChatUsername", alias="@type")
    chat_id: int
    username: str

    @staticmethod
    def read(q: dict) -> CheckChatUsername:
        return CheckChatUsername.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetExternalLinkInfo(BaseObject):
    """
    Returns information about an action to be done when the current user clicks an external link. Don't use this method for links from secret chats if link preview is disabled in secret chats
    
    Params:
        link (:class:`str`)
            The link
        
    """

    ID: str = Field("getExternalLinkInfo", alias="@type")
    link: str

    @staticmethod
    def read(q: dict) -> GetExternalLinkInfo:
        return GetExternalLinkInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .animated_chat_photo import AnimatedChatPhoto
from .minithumbnail import Minithumbnail
from .photo_size import PhotoSize
from ..base_object import BaseObject


class ChatPhoto(BaseObject):
    """
    Describes a chat or user profile photo
    
    Params:
        id (:class:`int`)
            Unique photo identifier
        
        added_date (:class:`int`)
            Point in time (Unix timestamp) when the photo has been added
        
        minithumbnail (:class:`Minithumbnail`)
            Photo minithumbnail; may be null
        
        sizes (:obj:`list[PhotoSize]`)
            Available variants of the photo in JPEG format, in different size
        
        animation (:class:`AnimatedChatPhoto`)
            Animated variant of the photo in MPEG4 format; may be null
        
    """

    ID: str = Field("chatPhoto", alias="@type")
    id: int
    added_date: int
    minithumbnail: typing.Optional[Minithumbnail] = None
    sizes: list[PhotoSize]
    animation: typing.Optional[AnimatedChatPhoto] = None

    @staticmethod
    def read(q: dict) -> ChatPhoto:
        return ChatPhoto.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckDatabaseEncryptionKey(BaseObject):
    """
    Checks the database encryption key for correctness. Works only when the current authorization state is authorizationStateWaitEncryptionKey
    
    Params:
        encryption_key (:class:`str`)
            Encryption key to check or set up
        
    """

    ID: str = Field("checkDatabaseEncryptionKey", alias="@type")
    encryption_key: str

    @staticmethod
    def read(q: dict) -> CheckDatabaseEncryptionKey:
        return CheckDatabaseEncryptionKey.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .closed_vector_path import ClosedVectorPath
from .emojis import Emojis
from .sticker import Sticker
from .thumbnail import Thumbnail
from ..base_object import BaseObject


class StickerSet(BaseObject):
    """
    Represents a sticker set
    
    Params:
        id (:class:`int`)
            Identifier of the sticker set
        
        title (:class:`str`)
            Title of the sticker set
        
        name (:class:`str`)
            Name of the sticker set
        
        thumbnail (:class:`Thumbnail`)
            Sticker set thumbnail in WEBP or TGS format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed
        
        thumbnail_outline (:obj:`list[ClosedVectorPath]`)
            Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner
        
        is_installed (:class:`bool`)
            True, if the sticker set has been installed by the current user
        
        is_archived (:class:`bool`)
            True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
        
        is_official (:class:`bool`)
            True, if the sticker set is official
        
        is_animated (:class:`bool`)
            True, is the stickers in the set are animated
        
        is_masks (:class:`bool`)
            True, if the stickers in the set are masks
        
        is_viewed (:class:`bool`)
            True for already viewed trending sticker sets
        
        stickers (:obj:`list[Sticker]`)
            List of stickers in this set
        
        emojis (:obj:`list[Emojis]`)
            A list of emoji corresponding to the stickers in the same order. The list is only for informational purposes, because a sticker is always sent with a fixed emoji from the corresponding Sticker object
        
    """

    ID: str = Field("stickerSet", alias="@type")
    id: int
    title: str
    name: str
    thumbnail: typing.Optional[Thumbnail] = None
    thumbnail_outline: list[ClosedVectorPath]
    is_installed: bool
    is_archived: bool
    is_official: bool
    is_animated: bool
    is_masks: bool
    is_viewed: bool
    stickers: list[Sticker]
    emojis: list[Emojis]

    @staticmethod
    def read(q: dict) -> StickerSet:
        return StickerSet.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class EncryptedCredentials(BaseObject):
    """
    Contains encrypted Telegram Passport data credentials
    
    Params:
        data (:class:`str`)
            The encrypted credentials
        
        hash_ (:class:`str`)
            The decrypted data hash
        
        secret (:class:`str`)
            Secret for data decryption, encrypted with the service's public key
        
    """

    ID: str = Field("encryptedCredentials", alias="@type")
    data: str
    hash_: str = Field(..., alias='hash')
    secret: str

    @staticmethod
    def read(q: dict) -> EncryptedCredentials:
        return EncryptedCredentials.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .file_type import FileType
from .network_type import NetworkType
from ..base_object import BaseObject


class NetworkStatisticsEntry(BaseObject):
    """
    Contains statistics about network usage
    
    """

    ID: str = Field("networkStatisticsEntry", alias="@type")


class NetworkStatisticsEntryCall(NetworkStatisticsEntry):
    """
    Contains information about the total amount of data that was used for calls
    
    Params:
        network_type (:class:`NetworkType`)
            Type of the network the data was sent through. Call setNetworkType to maintain the actual network type
        
        sent_bytes (:class:`int`)
            Total number of bytes sent
        
        received_bytes (:class:`int`)
            Total number of bytes received
        
        duration (:class:`float`)
            Total call duration, in seconds
        
    """

    ID: str = Field("networkStatisticsEntryCall", alias="@type")
    network_type: NetworkType
    sent_bytes: int
    received_bytes: int
    duration: float

    @staticmethod
    def read(q: dict) -> NetworkStatisticsEntryCall:
        return NetworkStatisticsEntryCall.construct(**q)


class NetworkStatisticsEntryFile(NetworkStatisticsEntry):
    """
    Contains information about the total amount of data that was used to send and receive files
    
    Params:
        file_type (:class:`FileType`)
            Type of the file the data is part of
        
        network_type (:class:`NetworkType`)
            Type of the network the data was sent through. Call setNetworkType to maintain the actual network type
        
        sent_bytes (:class:`int`)
            Total number of bytes sent
        
        received_bytes (:class:`int`)
            Total number of bytes received
        
    """

    ID: str = Field("networkStatisticsEntryFile", alias="@type")
    file_type: FileType
    network_type: NetworkType
    sent_bytes: int
    received_bytes: int

    @staticmethod
    def read(q: dict) -> NetworkStatisticsEntryFile:
        return NetworkStatisticsEntryFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import PassportElementType


class DeletePassportElement(BaseObject):
    """
    Deletes a Telegram Passport element
    
    Params:
        type_ (:class:`PassportElementType`)
            Element type
        
    """

    ID: str = Field("deletePassportElement", alias="@type")
    type_: PassportElementType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> DeletePassportElement:
        return DeletePassportElement.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .date import Date
from .input_file import InputFile
from ..base_object import BaseObject


class InputIdentityDocument(BaseObject):
    """
    An identity document to be saved to Telegram Passport
    
    Params:
        number (:class:`str`)
            Document number; 1-24 characters
        
        expiry_date (:class:`Date`)
            Document expiry date, if available
        
        front_side (:class:`InputFile`)
            Front side of the document
        
        reverse_side (:class:`InputFile`)
            Reverse side of the document; only for driver license and identity card
        
        selfie (:class:`InputFile`)
            Selfie with the document, if available
        
        translation (:obj:`list[InputFile]`)
            List of files containing a certified English translation of the document
        
    """

    ID: str = Field("inputIdentityDocument", alias="@type")
    number: str = Field(..., min_length=1, max_length=24)
    expiry_date: Date
    front_side: InputFile
    reverse_side: InputFile
    selfie: InputFile
    translation: list[InputFile]

    @staticmethod
    def read(q: dict) -> InputIdentityDocument:
        return InputIdentityDocument.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetChatSlowModeDelay(BaseObject):
    """
    Changes the slow mode delay of a chat. Available only for supergroups; requires can_restrict_members rights
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        slow_mode_delay (:class:`int`)
            New slow mode delay for the chat; must be one of 0, 10, 30, 60, 300, 900, 3600
        
    """

    ID: str = Field("setChatSlowModeDelay", alias="@type")
    chat_id: int
    slow_mode_delay: int

    @staticmethod
    def read(q: dict) -> SetChatSlowModeDelay:
        return SetChatSlowModeDelay.construct(**q)
